# Copyright 2014, Jan Nabbefeld
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# To Install:
#
# sudo yum -y install rpmdevtools && rpmdev-setuptree
# wget https://raw.github.com/odise/rpm-fleet/master/fleet.spec -O ~/rpmbuild/SPECS/fleet.spec
# wget https://raw.github.com/odise/rpm-fleet/master/fleet.service -O ~/rpmbuild/SOURCE/fleet.service
# wget https://github.com/coreos/fleet/releases/download/v%{version}/fleet-v%{version}-linux-amd64.tar.gz -O ~/rpmbuild/SOURCES/fleet-v%{version}-linux-amd64.tar.gz
# rpmbuild -bb ~/rpmbuild/SPECS/fleet.spec

%define debug_package %{nil}
%define etcd_user  %{name}
%define etcd_group %{name}
%define etcd_data  %{_localstatedir}/lib/%{name}

Name:      fleet
Version:   0.11.5
Release:   2
Summary:   A Distributed init System.
License:   Apache 2.0
URL:       https://github.com/coreos/fleet
Group:     System Environment/Daemons
Source0:   https://github.com/coreos/%{name}/releases/download/v%{version}/%{name}-v%{version}-linux-amd64.tar.gz
Source1:   %{name}.service
Source2:   %{name}.socket
Source3:   %{name}.conf
Buildroot: %{_tmppath}/%{name}-%{version}-%{release}-%(%{__id_u} -n)
Packager:  Jan Nabbefeld <jan.nabbefeld@kreuzwerker.de>
Requires(pre): shadow-utils
Requires(post): /bin/systemctl
Requires(preun): /bin/systemctl
Requires(postun): /bin/systemctl

%description
Fleet ties together systemd and etcd into a distributed init system. 
Think of it as an extension of systemd that operates at the cluster level
instead of the machine level. This project is very low level and is 
designed as a foundation for higher order orchestration.

%prep
%setup -n %{name}-v%{version}-linux-amd64

%build
rm -rf %{buildroot}

echo  %{buildroot}

%install
install -d -m 755 %{buildroot}/%{_bindir}
install    -m 755 %{_builddir}/%{name}-v%{version}-linux-amd64/fleetd    %{buildroot}/%{_bindir}
install    -m 755 %{_builddir}/%{name}-v%{version}-linux-amd64/fleetctl %{buildroot}/%{_bindir}

install -d -m 755 %{buildroot}/usr/share/doc/%{name}-v%{version}
install    -m 644 %{_builddir}/%{name}-v%{version}-linux-amd64/README.md    %{buildroot}/%{_defaultdocdir}/%{name}-v%{version}

install -d -m 755 %{buildroot}/%{_prefix}/lib/systemd/system
install    -m 644 %_sourcedir/%{name}.service    %{buildroot}/%{_prefix}/lib/systemd/system/%{name}.service
install    -m 644 %_sourcedir/%{name}.socket    %{buildroot}/%{_prefix}/lib/systemd/system/%{name}.socket

install -d -m 755 %{buildroot}/%{_sysconfdir}/%{name}
install    -m 644 %_sourcedir/%{name}.conf       %{buildroot}/%{_sysconfdir}/%{name}/%{name}.conf

%clean
rm -rf %{buildroot}

#%pre
#getent group %{etcd_group} >/dev/null || groupadd -r %{etcd_group}
#getent passwd %{etcd_user} >/dev/null || /usr/sbin/useradd --comment "etcd Daemon User" --shell /bin/bash -M -r -g %{etcd_group} --home %{etcd_data} %{etcd_user}

%post
systemctl enable %{name} > /dev/null 2>&1
systemctl start %{name} > /dev/null 2>&1

%preun
if [ $1 = 0 ]; then
  systemctl stop %{name} > /dev/null 2>&1
  systemctl disable %{name} > /dev/null 2>&1
fi

%files
%defattr(-,root,root)
%{_bindir}/%{name}*
%{_defaultdocdir}/%{name}-v%{version}/*.md
%{_prefix}/lib/systemd/system/%{name}.service
%{_prefix}/lib/systemd/system/%{name}.socket
%config(noreplace) %{_sysconfdir}/%{name}/%{name}.conf

%changelog
* Thu Oct 29 2015 Jonas Svatos <jonas.svatos@etnetera.cz> 0.2.1
- Fix systemd unit location, add socket unit, add config file.
* Thu Oct 29 2015 Jonas Svatos <jonas.svatos@etnetera.cz> 0.2.0
- New upstream version.
* Wed Oct 08 2014 Jan Nabbefeld <jan.nabbefeld@kreuzwerker.de> 0.1.0
- Initial spec.
